#property indicator_chart_window

// Input parameters
extern int MA_Period1 = 5;
extern int MA_Period2 = 10;
extern int MA_Period3 = 20;

// Indicator buffers
double Buffer[];

//+------------------------------------------------------------------+
//| Custom indicator initialization function                         |
//+------------------------------------------------------------------+
int init()
{
    // Set indicator buffers
    SetIndexBuffer(0, Buffer, INDICATOR_DATA);

    // Set indicator label
    SetIndexLabel(0, "Hybrid Indicator");

    // Set Accumulation/Distribution as the first indicator
    string firstIndicatorName = "Accumulation/Distribution";
    if (!SetIndexBuffer(1, NULL) || !SetIndexLabel(1, firstIndicatorName))
    {
        Print("Failed to set ", firstIndicatorName, " indicator.");
        return INIT_FAILED;
    }

    // Set Moving Averages as the next three indicators
    string[] maLabels = { "MA1", "MA2", "MA3" };
    int[] maHandles;

    for (int i = 0; i < 3; i++)
    {
        int handle = iMA(NULL, 0, MA_Period1 * (i + 1), 0, MODE_SMMA, PRICE_CLOSE);
        if (handle <= 0)
        {
            Print("Failed to create ", maLabels[i], " indicator.");
            return INIT_FAILED;
        }
        maHandles[i] = handle;

        if (!CopyBuffer(handle, 0, 0, Bars, Buffer))
        {
            Print("Failed to copy buffer for ", maLabels[i], " indicator.");
            return INIT_FAILED;
        }

        SetIndexBuffer(i + 2, Buffer, INDICATOR_DATA);
        SetIndexLabel(i + 2, maLabels[i]);
    }

    return INIT_SUCCEEDED;
}

//+------------------------------------------------------------------+
//| Custom indicator deinitialization function                       |
//+------------------------------------------------------------------+
int deinit()
{
    // Clean up indicator handles
    for (int i = 0; i < 3; i++)
    {
        IndicatorRelease(maHandles[i]);
    }

    return 0;
}

//+------------------------------------------------------------------+
//| Custom indicator iteration function                              |
//+------------------------------------------------------------------+
int start()
{
    int limit = Bars - IndicatorCounted();
    if (limit > Bars || limit <= 0)
        limit = Bars;

    for (int i = limit - 1; i >= 0; i--)
    {
        // Calculate Accumulation/Distribution value
        double adValue = iAD(NULL, 0);

        // Calculate Moving Average values using Accumulation/Distribution
        double maValue1 = iMAOnArray(Buffer, Bars, MA_Period1 * (i + 1), 0, MODE_SMMA, i) + adValue;
        double maValue2 = iMAOnArray(Buffer, Bars, MA_Period2 * (i + 1), 0, MODE_SMMA, i) + adValue;
        double maValue3 = iMAOnArray(Buffer, Bars, MA_Period3 * (i + 1), 0, MODE_SMMA, i) + adValue;

        // Store the hybrid indicator value in the buffer
        Buffer[i] = adValue + maValue1 + maValue2 + maValue3;
    }

    return 0;
}